@@ -1963,10 +1963,1171 @@ sub BoolOperands {
 
 	my $realNumber = $class->RealNumber();
 	if($realNumber) {
+		return $realNumber;
+	}
 
+	my $string = $class->String();
+	if($string) {
+		return $string;
+	}
+
+	my $scalarVariable = $class->ScalarVariable();
+	if($scalarVariable) {
+		return $scalarVariable;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $classAccessor = $class->ClassAccessor();
+	if($classAccessor) {
+		return $classAccessor;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $functionReturn = $class->FunctionReturn();
+	if($functionReturn) {
+		return $functionReturn;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	return 0;
+}
+
+sub BoolOperator {
+	my ($class) = @_;
+
+	my $greaterThan = $class->GreaterThan();
+	if($greaterThan) {
+		return $greaterThan;
+	}
+
+	my $lessThan = $class->LessThan();
+	if($lessThan) {
+		return $lessThan;
+	}
+
+	my $equals = $class->Equals();
+	if($equals) {
+		return $equals;
+	}
+
+	my $greaterThanEquals = $class->GreaterThanEquals();
+	if($greaterThanEquals) {
+		return $greaterThanEquals;
+	}
+
+	my $lessThanEquals = $class->LessThanEquals();
+	if($lessThanEquals) {
+		return $lessThanEquals;
+	}
+
+	my $stringEquals = $class->StringEquals();
+	if($stringEquals) {
+		return $stringEquals;
+	}
+
+	my $stringNotEquals = $class->StringNotEquals();
+	if($stringNotEquals) {
+		return $stringNotEquals;
+	}
+
+	my $notEquals = $class->NotEqulas();
+	if($notEquals) {
+		return $notEquals;
+	}
+
+	my $logicalAnd = $class->LogicalAnd();
+	if($logicalAnd) {
+		return $logicalAnd;
+	}
+
+	my $logicalOr = $class->LogicalOr();
+	if($logicalOr) {
+		return $logicalOr;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	return 0;
+}
+
+sub ElsIf {
+	my ($class) = @_;
+	my $elsIf = "";
+
+	my $elsIfChain = $class->ElsIfChain();
+	if($elsIfChain) {
+		$elsIf .= $elsIfChain;
+	} else {
+		return $elsIf;
+	}
+
+	my $rightElsIf = $class->ElsIf();
+	if($rightElsIf) {
+		$elsIf .= $rightElsIf;
+	} else {
+		return 0;
+	}
+
+	return $elsIf;
+}
+
+sub ElsIfChain {
+	my ($class) = @_;
+	my $elsIfChain = "";
+
+	my $tokenIf = $class->TokenIf();
+	if($tokenIf) {
+		$elsIfChain .= $tokenIf;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$elsIfChain .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $boolExpression = $class->BoolExpression();
+	if($boolExpression) {
+		$elsIfChain .= $boolExpression;
+	} else {
+		return 0;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$elsIfChain .= $rParen;
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$elsIfChain .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $elsIfChain;
+}
+
+sub Else {
+	my ($class) = @_;
+	my $else = "";
+
+	my $tokenElse = $class->TokenElse();
+	if($tokenElse) {
+		$else .= $tokenElse;
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$else .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $else;
+}
+
+sub Statement {
+	my ($class) = @_;
+	my $statement = "";
+
+	my $variableDeclaration = $class->VariableDeclaration();
+	if($variableDeclaration) {
+		return $variableDeclaration;
+	}
+
+	my $functionCall = $class->FunctionCall();
+	if($functionCall) {
+		return $functionCall;
+	}
+
+	my $calssFunctionCall = $class->ClassFunctionCall();
+	if($classFunctionCall) {
+		return $classFunctionCall;
+	}
+
+	my $objectCall = $class->ObjectCall();
+	if($objectCall) {
+		return $objectCall;
+	}
+
+	my $assignment = $class->Assignment();
+	if($assignment) {
+		return $assignment;
+	}
+
+	my $return = $class->Return();
+	if($return) {
+		return $return;
+	}
+
+	my $last = $class->Last();
+	if($last) {
+		return $last;
+	}
+
+	my $next = $class->Next();
+	if($next) {
+		return $next;
+	}
+
+	return 0;
+}
+
+sub ClassFunctionCall {
+	my ($class) = @_;
+	my $classFunctionCall = "";
+
+	my $tokenClass = $class->TokenClass();
+	if($tokenClass) {
+		return $tokenClass;
+	} else {
+		return 0;
+	}
+
+	my $dot = $class->Dot();
+	if($dot) {
+		return $dot;
+	} else {
+		return 0;
+	}
+
+	my $functionName = $class->FunctionName();
+	if($funcitonName) {
+		return $functionName;
+	} else {
+		return 0;
 	}
 }
 
+sub ObjectCall {
+	my ($class) = @_;
+	my $objectCall = "";
+
+	my $objectFunctionCall = $class->ObjectFunctionCall();
+	if($objectFunctionCall) {
+		$objectCall .= $objectFunctionCall;
+	} else {
+		return 0;
+	}
+
+	my $semiColon = $class->SemiColon();
+	if($semiColon) {
+		$objectCall .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	return $objectCall;
+}
+
+sub variableDeclaration {
+	my ($class) = @_;
+
+	my $arrayDeclaration = $class->ArrayDeclaration();
+	if($arrayDeclaration) {
+		return $arrayDeclaration;
+	}
+
+	my $hashDeclaration = $class->HashDeclaration();
+	if($hashDeclaration) {
+		return $hashDeclaration;
+	}
+
+	my $scalarDeclaration = $class->ScalarDeclaration();
+	if($scalarDeclaration) {
+		return $scalarDeclaration;
+	}
+
+	return 0;
+}
+
+sub scalarDeclaration {
+	my ($class) = @_;
+	my $scalarDeclaration = "";
+
+	my $var = $class->Var();
+	if($var) {
+		$scalarDeclaration .= $var;
+	} else {
+		return 0;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		$scalarDeclaration .= $variableName;
+	} else {
+		return 0;
+	}
+
+	my $equal = $class->Equal();
+	if($equal) {
+		$scalarDeclaration .= $equal;
+	} else {
+		return 0;
+	}
+
+	my $value = $class->Value();
+	if($value) {
+		$scalarDeclaration .= $value;
+	} else {
+		return 0;
+	}
+
+	my $semiColon = $class->SemiColon();
+	if($semiColon) {
+		$scalarDeclaration .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	return $scalarDeclaration;
+}
+
+sub Var {
+	my ($class) = @_;
+	my $var = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"value"} eq "var") {
+		$var .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $var;
+}
+
+sub VariableName {
+	my ($class) = @_;
+	my $variableName = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "symbol") {
+		$variableName .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $variableName;
+}
+
+sub Value {
+	my ($class) = @_;
+	my $value = "";
+
+	my $rhs = $class->RHS();
+	if($rhs) {
+		$value .= $rhs;
+	} else {
+		return 0;
+	}
+
+	return $value;
+}
+
+sub Number {
+	my ($class) = @_;
+	my $number = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Number") {
+		$number .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $number;
+}
+
+sub RealNumber {
+	my ($class) = @_;
+	my $realNumber = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "RealNumber") {
+		$realNumber .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $realNumber;
+}
+
+sub String {
+	my ($class) = @_;
+	my $string = "";
+
+	my $lQuote = $class->LQuote();
+	if($lQuote) {
+		$string .= $lQuote;
+	} else {
+		return 0;
+	}
+
+	my $stringValue = $class->StringValue();
+	if($stringValue) {
+		$string .= $stringValue;
+	} else {
+		return 0;
+	}
+
+	my $rQuote = $class->RQuote();
+	if($rQuote) {
+		$string .= $rQuote;
+	} else {
+		return 0;
+	}
+
+	return $string;
+}
+
+sub LQuote {
+	my ($class) = @_;
+	my $lQuote = "";
+
+	my $quote = $class->Quote();
+	if($quote) {
+		$lQuote .= $quote;
+	} else {
+		return 0;
+	}
+
+	return $lQuote;
+}
+
+sub RQuote {
+	my ($class) = @_;
+	my $rQuote = "";
+
+	my $quote = $class->Quote();
+	if($quote) {
+		$rQuote .= $quote;
+	} else {
+		return 0;
+	}
+
+	return $rQuote;
+}
+
+sub StringValue {
+	my ($class) = @_;
+	my $stringValue;
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "String") {
+		$stringValue .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $stringValue;
+}
+
+sub ArrayDeclaration {
+	my ($class) = @_;
+	my $arrayDeclaration = "";
+
+	my $var = $class->Var();
+	if($var) {
+		$arrayDeclaration .= $var;
+	} else {
+		return 0;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		$arrayDeclaration .= $variableName;
+	} else {
+		return 0;
+	}
+
+	my $equal = $class->Equal();
+	if($equal) {
+		$arrayDeclaration .= $equal;
+	} else {
+		return 0;
+	}
+
+	my $arrayList = $class->ArrayList();
+	if($arrayList) {
+		$arrayDeclaration .= $arrayList;
+	} else {
+		return 0;
+	}
+
+	my $semiColon = $class->SemiColon();
+	if($semiColon) {
+		$arrayDeclaration .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	return $arrayDeclaration;
+}
+
+sub ArrayList {
+	my ($class) = @_;
+	my $arrayList = "";
+
+	my $lBracket = $class->LBracket();
+	if($lBracket) {
+		$arrayList .= $lBracket;
+	} else {
+		return 0;
+	}
+
+	my $listElements = $class->ListElements();
+	if($semiColon) {
+		$arrayList .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	my $rBracket = $class->RBracket();
+	if($rBracket) {
+		$arrayList .= $rBracket;
+	} else {
+		return 0;
+	}
+
+	return $rBracket;
+}
+
+sub ListElements {
+	my ($class) = @_;
+	my $listElements = "";
+
+	my $listElement = $class->ListElement();
+	if($listElement) {
+		my $listElements .= $listElement;
+	}
+
+	my $comma = $class->Comma();
+	if($comma) {
+		my $listElements .= $comma;
+	} else {
+		return $listElements;
+	}
+
+	my $rightListElements = $class->ListElements();
+	if($rightListElements) {
+		$listElements .= $rightListElements;
+	}
+
+	return $listElements;
+}
+
+sub ListElement {
+	my ($class) = @_;
+
+	my $realNumber = $class->RealNumber();
+	if($realNumber) {
+		return $realNumber;
+	}
+
+	my $string = $class->String();
+	if($string) {
+		return $string;
+	}
+
+	my $classfunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $functionReturn = $class->FunctionReturn();
+	if($functionReturn) {
+		return $functionReturn;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $arrayList = $class->ArrayList();
+	if($arrayList) {
+		return $arrayList;
+	}
+
+	my $hashRef = $class->HashRef();
+	if($hashRef) {
+		return $hashRef;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		return $variableName;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	return 0;
+}
+
+sub HashDeclaration {
+	my ($class) = @_;
+	my $hashDeclaration = "";
+
+	my $var = $class->Var();
+	if($var) {
+		$hashDeclaration .= $var;
+	} else {
+		return 0;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		$hashDeclaration .= $variableName;
+	} else {
+		return 0;
+	}
+
+	my $equal = $class->Equal();
+	if($equal) {
+		$hashDeclaration .= $equal;
+	} else {
+		return 0;
+	}
+
+	my $hashRef = $class->HashRef();
+	if($hashRef) {
+		$hashDeclaration .= $hashRef;
+	} else {
+		return 0;
+	}
+
+	my $semiColon = $class->SemiColon();
+	if($semiColon) {
+		$hashDeclaration .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	return $hashDeclaration;
+}
+
+sub HashRef {
+	my ($class) = @_;
+	my $hashRef = "";
+
+	my $lBrace = $class->LBrace();
+	if($lBrace) {
+		my $hashRef .= $lBrace;
+	} else {
+		return 0;
+	}
+
+	my $keyValuePairs = $class->KeyValuePairs();
+	if($keyValuePairs) {
+		my $hashRef .= $keyValuePairs;
+	} else {
+		return 0;
+	}
+
+	my $rBrace = $class->RBrace();
+	if($rBrace) {
+		my $hashRef .= $rBrace;
+	} else {
+		return 0;
+	}
+
+	return $hashRef;
+}
+
+sub KeyValuePairs {
+	my ($class) = @_;
+	my $keyValuePairs = "";
+
+	my $keyValue = $class->KeyValue();
+	if($keyValue) {
+		$keyValuePairs .= $keyValue;
+	} else {
+		return 0;
+	}
+
+	my $comma = $class->Comma();
+	if($comma) {
+		$keyValuePairs .= $comma;
+	} else {
+		return $keyValuePairs;
+	}
+
+	my $rightKeyValuePairs = $class->KeyValuePairs();
+	if($rightKeyValuePairs) {
+		$keyValuePairs .= $rightKeyValuePairs;
+	} else {
+		return 0;
+	}
+
+	return $keyValuePairs;
+}
+
+sub KeyValue {
+	my ($class) = @_;
+	my $keyValue = "";
+
+	my $pairKey = $class->PairKey();
+	if($pairKey) {
+		$keyValue .= $pairKey;
+	} else {
+		return 0;
+	}
+
+	my $colon = $class->Colon();
+	if($colon) {
+		$keyValue .= $colon;
+	} else {
+		return 0;
+	}
+
+	my $pairValue = $class->PairValue();
+	if($pairValue) {
+		$keyValue .= $pairValue;
+	} else {
+		return 0;
+	}
+
+	return $pairValue;
+}
+
+sub PairKey {
+	my ($class) = @_;
+
+	my $number = $class->Number();
+	if($number) {
+		return $number;
+	}
+
+	my $stirng = $class->String();
+	if($string) {
+		return $string;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $functionReturn = $class->FunctionReturn();
+	if($functionReturn) {
+		return $functionReturn;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		return $variableName;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	return 0;
+}
+
+sub PairValue {
+	my ($class) = @_;
+
+	my $realNumber = $class->RealNumber();
+	if($realNumber) {
+		return $realNumber;
+	}
+
+	my $stirng = $class->String();
+	if($string) {
+		return $string;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $functionReturn = $class->FunctionReturn();
+	if($functionReturn) {
+		return $functionReturn;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		return $variableName;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $arrayList = $class->ArrayList();
+	if($arrayList) {
+		return $arrayList;
+	}
+
+	my $hashRef = $class->HashRef();
+	if($hashRef) {
+		return $hashRef;
+	}
+
+	return 0;
+}
+
+sub FunctionCall {
+	my ($class) = @_;
+	my $funcitonCall;
+
+	my $functionName = $class->FunctionName();
+	if($funcitonName) {
+		$functionCall .= $funcitonName;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$functionCall .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $parameters = $class->Parameters();
+	if($parameters) {
+		$functionCall .= $parameters;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$functionCall .= $rParen;
+	} else {
+		return 0;
+	}
+
+	my $semiColon = $class->SemiColon();
+	if($semiColon) {
+		$functionCall .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	return $functionCall;
+}
+
+sub Parameters {
+	my ($class) = @_;
+	my $parameters;
+
+	my $param .= $class->Param();
+	if($param) {
+		$parameters .= $param;
+	} else {
+		return 0;
+	}
+
+	my $comma .= $class->Comma();
+	if($comma) {
+		$parameters .= $comma;
+	} else {
+		return $parameters;
+	}
+
+	my $rightParameters = $class->Parameters();
+	if($rightParameters) {
+		$parameters .= $rightParameters;
+	} else {
+		return 0;
+	}
+
+	return $parameters;
+}
+
+sub Param {
+	my ($class) = @_;
+
+	my $realNumber = $class->RealNumber();
+	if($realNumber) {
+		return $realNumber;
+	}
+
+	my $stirng = $class->String();
+	if($string) {
+		return $string;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $functionReturn = $class->FunctionReturn();
+	if($functionReturn) {
+		return $functionReturn;
+	}
+
+	my $variableName = $class->VariableName();
+	if($variableName) {
+		return $variableName;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $arrayList = $class->ArrayList();
+	if($arrayList) {
+		return $arrayList;
+	}
+
+	my $hashRef = $class->HashRef();
+	if($hashRef) {
+		return $hashRef;
+	}
+
+	return 0;
+}
+
+sub Assignment {
+	my ($class) = @_;
+
+	my $scalarAssignment = $class->ScalarAssignment();
+	if($scalarAssignment) {
+		return $scalarAssignment;
+	}
+
+	my $arrayAssignment = $class->ArrayAssignment();
+	if($arrayAssignment) {
+		return $arrayAssignment;
+	}
+
+	my $hashAssignment = $class->HashAssignment();
+	if($hashAssignment) {
+		return $hashAssignment;
+	}
+
+	my $accessorAssignment = $class->AccessorAssignment();
+	if($accessorAssignment) {
+		return $accessorAssignment;
+	}
+
+	return 0;
+}
+
+sub ScalarAssignment {
+	my ($class) = @_;
+	my $scalarAssignment = "";
+
+	my $scalarVariable = $class->ScalarVariable();
+	if($scalarVariable) {
+		$scalarAssignment .= $scalarVariable;
+	} else {
+		return 0;
+	}
+
+	my $equal = $class->Equal();
+	if($equal) {
+		$scalarAssignment .= $equal;
+	} else {
+		return 0;
+	}
+
+	my $rhs = $class->RHS();
+	if($rhs) {
+		$scalarAssignment .= $rhs;
+	} else {
+		return 0;
+	}
+
+	my $semiColon = $class->SemiColon();
+	if($semiColon) {
+		$scalarAssignment .= $semiColon;
+	} else {
+		return 0;
+	}
+
+	return $scalarAssignment;
+}
+
+sub ScalarVariable {
+	my ($class) = @_;
+	my $scalarVariable = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Symbol") {
+		$scalarVariable .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $scalarVariable;
+}
+
+sub RHS {
+	my ($class) = @_;
+
+	my $realNumber = $class->RealNumber();
+	if($realNumber) {
+		return $realNumber;
+	}
+
+	my $stirng = $class->String();
+	if($string) {
+		return $string;
+	}
+
+	my $classFunctionReturn = $class->ClassFunctionReturn();
+	if($classFunctionReturn) {
+		return $classFunctionReturn;
+	}
+
+	my $functionReturn = $class->FunctionReturn();
+	if($functionReturn) {
+		return $functionReturn;
+	}
+
+	my $embedBlock = $class->EmbedBlock();
+	if($embedBlock) {
+		return $embedBlock;
+	}
+
+	my $arrayElement = $class->ArrayElement();
+	if($arrayElement) {
+		return $arrayElement;
+	}
+
+	my $hashElement = $class->HashElement();
+	if($hashElement) {
+		return $hashElement;
+	}
+
+	my $arrayList = $class->ArrayList();
+	if($arrayList) {
+		return $arrayList;
+	}
+
+	my $hashRef = $class->HashRef();
+	if($hashRef) {
+		return $hashRef;
+	}
+
+	my $scalarVariable = $class->ScalarVariable();
+	if($scalarVariable) {
+		return $scalarVariable;
+	}
+
+	my $calc = $class->Calc();
+	if($calc) {
+		return $calc;
+	}
+
+	my $classAccessor = $class->classAccessor();
+	if($classAccessor) {
+		return $classAccessor;
+	}
+
+	my $stdin = $class->STDIN();
+	if($stdin) {
+		return $stdin;
+	}
+
+	my $objectFunctionCall = $class->ObjectFunctionCall();
+	if($objectFunctionCall) {
+		return $objectFunctionCall;
+	}
+
+	return 0;
+}
+
+sub FunctionReturn {
+	my ($class) = @_;
+	my $functionReturn = "";
+
+	my $functionName = $class->FunctionName();
+	if($functionName) {
+		$functionReturn .= $functionName;
+	} else {
+		return 0;
+	}
+
+	my $lParen = $class->LParen();
+	if($lParen) {
+		$functionReturn .= $lParen;
+	} else {
+		return 0;
+	}
+
+	my $parameters = $class->Parameters();
+	if($parameters) {
+		$functionReturn .= $parameters;
+	}
+
+	my $rParen = $class->RParen();
+	if($rParen) {
+		$functionReturn .= $rParen;
+	} else {
+		return 0;
+	}
+
+	return 0;
+}
+
+
 
 1;
 
@@ -1976,7 +3137,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
     my ($class) = @_;
@@ -1999,16 +3160,12 @@ __END__
 
 =head1 NAME
 
-Lang::HL::Syntax - Syntax Check for HL
+Lang::HL::Syntax
 
 =head1 SYNOPSIS
 
 	$> hle <directory>
 
-=head1 DESCRIPTION
-
-An another compiler for HL. A work in progress.
-
 =head1 AUTHOR
 
 Rajkumar Reddy
